#
# spec file for package junit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           junit
Version:        4.13.2
Release:        8.4
Summary:        Java regression test package
License:        EPL-1.0
Group:          Development/Libraries/Java
URL:            https://junit.org/junit4/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.xml
Patch0:         0001-Port-to-hamcrest-2.2.patch
Patch1:         0002-remove-usages-of-deprecated-org.junit.Assert.assertT.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  hamcrest >= 2.2
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
Requires:       hamcrest >= 2.2
Provides:       %{name}-demo = %{version}-%{release}
Obsoletes:      %{name}-demo < %{version}-%{release}
Provides:       %{name}4-demo = %{version}-%{release}
Obsoletes:      %{name}4-demo < %{version}-%{release}
Provides:       %{name}4 = %{version}-%{release}
Obsoletes:      %{name}4 < %{version}-%{release}
BuildArch:      noarch

%description
JUnit is a regression testing framework written by Erich Gamma and Kent Beck.
It is used by the developer who implements unit tests in Java.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML
Provides:       %{name}4-javadoc = %{version}-%{release}
Obsoletes:      %{name}4-javadoc < %{version}-%{release}

%description javadoc
Javadoc for %{name}.

%package manual
Summary:        Manual for %{name}
Group:          Documentation/Other
Provides:       %{name}4-manual = %{version}-%{release}
Obsoletes:      %{name}4-manual < %{version}-%{release}

%description manual
Documentation for %{name}.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
cp %{SOURCE1} build.xml

find . -type f -name "*.jar" -or -name "*.class" | xargs -t rm -rf

%build
build-jar-repository -s lib hamcrest
ant jar javadoc

%install
# jars
install -d -m 755 %{buildroot}%{_javadir}
install -m 644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
# compat symlink
ln -sf %{_javadir}/%{name}.jar %{buildroot}%{_javadir}/%{name}4.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%check

cat > test.java <<EOF
import org.junit.Assert;
class test {

    public static void main(String[] args) {
        Assert.fail("Hello world from junit");
    }

}
EOF
javac -source 8 -target 8 -cp %{buildroot}/%{_javadir}/%{name}.jar test.java
java -cp %{buildroot}/%{_javadir}/%{name}.jar: test 2>&1 | \
   grep 'Exception in thread "main" java.lang.AssertionError: Hello world from junit'

%files -f .mfiles
%license LICENSE-junit.txt
%doc CODING_STYLE.txt README.md acknowledgements.txt
%{_javadir}/%{name}4.jar

%files javadoc
%license LICENSE-junit.txt
%{_javadocdir}/%{name}

%files manual
%license LICENSE-junit.txt
%doc doc/*

%changelog
* Thu May 23 2024 Fridrich Strba <fstrba@suse.com>
- Require hamcrest >= 2.2 to resolve choice of providers
* Sat Apr 27 2024 Fridrich Strba <fstrba@suse.com>
- Generate anew the ant build system using the maven pom.xml
- Fetch sources from github by source service and filter out stale
  hamcrest binaries.
- Port to hamcrest 2.2 unconditionally
- Added patch:
  * 0002-remove-usages-of-deprecated-org.junit.Assert.assertT.patch
    + upstream patch to replace deprecated assertThat
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Sep 21 2023 Fridrich Strba <fstrba@suse.com>
- Let ant build with --release 8 if the compiler knows that option.
  This allows us to avoid incompatible exception declarations
  in ObjectInputStream.GetField.get(String,Object) in java >= 20
* Thu Mar 23 2023 Fridrich Strba <fstrba@suse.com>
- Conditionalize the spec file so that junit can be built with
  both hamcrest 1.3 and 2.2 from the same sources
* Thu Jun  9 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * 0001-Port-to-hamcrest-2.2.patch
    + do not use the org.hamcrest.Factory that was removed in
    hamcrest 2.x and should have been an internal annotation
    only
    + fix some incompatibilities with template types in matchers
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Build with source/target levels 8
* Sun Dec 12 2021 Dirk Müller <dmueller@suse.com>
- update to 4.13.2:
  * Mark ThreadGroups created by FailOnTimeout as daemon groups
  * Only create ThreadGroups if FailOnTimeout.lookForStuckThread is true.
  * Fix NotSerializableException with AssumptionViolatedException
  * Security fix: TemporaryFolder now limits access to temporary folders on
    Java 1.7 or later (CVE-2020-1945, bsc#1171696)
  * Make FrameworkField constructor public
* Tue Apr  7 2020 Fridrich Strba <fstrba@suse.com>
- Upgrade to 4.13
- Removed patches:
  * junit-jdk10.patch
  * junit-jdk11.patch
    + not needed with this version
* Mon Feb  4 2019 Fridrich Strba <fstrba@suse.com>
- Add OSGi manifest to the jar file
- Package the manual
- BuildRequire and Require hamcrest-core, since the package does
  strictly depend on hamcrest-core only.
* Mon Jan 21 2019 Jan Engelhardt <jengelh@inai.de>
- Trim repeated metadata from description.
* Wed Dec 26 2018 Fridrich Strba <fstrba@suse.com>
- Upgrade to 4.12
- Removed patches:
  * junit-jdk8.patch
  * junit-jdk9.patch
  * junit-no-hamcrest-src.patch
    + Integrated directly in the added build.xml file
* Wed Jul 11 2018 fstrba@suse.com
- Added patch:
  * junit-jdk11.patch
    + Fix build with jdk11
    + Don't override removed SecurityManager methods
* Mon Dec 18 2017 fstrba@suse.com
- Run fdupes on documentation
* Mon Dec 18 2017 dimstar@opensuse.org
- Harden and fix the test suite:
  + org.framework.junit is deprecated since junit 4.0
  + Ensure we fail check when junit no longer returns what we
    expect it to (error code checking is useless, since Assert
    returns !0, like any other failure to start the test).
* Mon Dec 18 2017 fstrba@suse.com
- Added patch:
  * junit-jdk10.patch
    + Remove a function getInCheck from NoExitSecurityManager,
    since it does not exist in the extended class in jdk10 and is
    deprecated in previous versions
* Fri Sep  8 2017 fstrba@suse.com
- Added patch:
  * junit-jdk9.patch
    + Build with java source and target levels 1.6 in order to
    allow building with jdk9
* Fri May 19 2017 dziolkowski@suse.com
- New build dependency: javapackages-local
* Tue Jul 28 2015 tchvatal@suse.com
- Add patch to build with jdk8:
  * junit-jdk8.patch
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Fri Oct 25 2013 mvyskocil@suse.com
- Update to 4.11
  * Matchers: Upgrade to Hamcrest 1.3
    no longer included junit jar
  * Parameterized Tests
  * Specify Test execution order
  * New maven artifact 'junit:junit' w/o builtin hamcrest
  * Number of improvements into Rules
- Drop jdk7-testfailure.patch, fixed upstream
- Add junit-no-hamcrest-src.patch, don't bundle hamcrest into junit.jar
- Use SourceUrl for release tarball and pom
- Don't inject OSGI manifest, it breaks junit.jar
- Provide/obsolete package junit4
* Fri Aug 23 2013 mvyskocil@suse.com
- disable javadoc build
* Thu Sep 11 2008 mvyskocil@suse.cz
- Use gcc-java for build
- Update 3.8.2 (a new build.xml)
- Removed a java14compat
- Removed javadoc postin/postun
- Add a cpl-v10.html
* Thu Mar 29 2007 ro@suse.de
- added unzip to buildreq
* Tue Sep 26 2006 skh@suse.de
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul 28 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 3.8.1 from JPackage.org
* Thu Sep 16 2004 skh@suse.de
- Fix prerequires of javadoc subpackage
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 3.8.1 (JPackage 1.5)
